# ######################################################################
# Copyright (c) 2005-2006 Michael Alyn Miller <malyn@strangeGizmo.com>
# All rights reserved.
# vi:et:sts=4
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice unmodified, this list of conditions, and the following
#    disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. Neither the name of Michael Alyn Miller nor the names of the
#    contributors to this software may be used to endorse or promote
#    products derived from this software without specific prior written
#    permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.



# ######################################################################
# IMPORTS
#

# Jython imports.
import org.python.util.InteractiveConsole

# Hermes imports.
from hermes import *



# ######################################################################
# PYTHON CONSOLE IMPLEMENTATION
#

class ConsoleDone(Exception):
    """Raised when the user has decided to exit the console."""


class HermesPythonConsole(org.python.util.InteractiveConsole):
    """Extends Jython's InteractiveConsole class to provide a way of
    receiving input using the Hermes API."""

    def raw_input(self, promptText):
        # Get the user's input.
        buf = textPrompt(promptText, 72)
        if buf == 'exit' or buf == 'quit':
            raise ConsoleDone

        # Return the input.
        return buf



# ######################################################################
# MAIN ENTRY POINT
#

def main():
    # Initialize the Hermes Python Console.
    console = HermesPythonConsole()

    # Let the user interact with the console.
    try:
        console.interact('Hermes Python Console v1.0 -- type "exit" when done')
    except ConsoleDone:
        # Ignore ConsoleDone exceptions; they indicate that the console
        # was exited cleanly.
        pass


if __name__ == '__main__':
    main()
